{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:1.0"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk3_unifiedgenotyper.cwl/bam_file"
                },
                {
                    "type": "File",
                    "id": "#gatk3_unifiedgenotyper.cwl/interval"
                },
                {
                    "type": "string",
                    "id": "#gatk3_unifiedgenotyper.cwl/job_uuid"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk3_unifiedgenotyper.cwl/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk3_unifiedgenotyper.cwl/snp_ref"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.gatk3_unifiedgenotyper.time.json') python /opt/gatk3_genomel_variant_calling.py -j $(inputs.job_uuid) -r $(inputs.reference.path) -i $(inputs.interval.path) -s $(inputs.snp_ref.path) -c 25 -t unifiedgenotyper"
                }
            ],
            "id": "#gatk3_unifiedgenotyper.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.gatk3_unifiedgenotyper.time.json')"
                    },
                    "id": "#gatk3_unifiedgenotyper.cwl/time_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk3_unifiedgenotyper.cwl/vcf_list"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-exome-variant-detection/genomel_variant_calling:6.0"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#picard_sortvcf.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#picard_sortvcf.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "id": "#picard_sortvcf.cwl/reference_dict"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "I=",
                            "separate": false
                        }
                    },
                    "inputBinding": {
                        "position": 99
                    },
                    "id": "#picard_sortvcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.' + inputs.output_prefix + '.vcf.gz')"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_sortvcf.cwl/sorted_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.picard_sortvcf.time.json')"
                    },
                    "id": "#picard_sortvcf.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.picard_sortvcf.time.json') java -Xmx100G -XX:ParallelGCThreads=30 -jar /opt/picard.jar SortVcf CREATE_INDEX=true OUTPUT=$(inputs.job_uuid + '.' + inputs.output_prefix + '.vcf.gz') SEQUENCE_DICTIONARY=$(inputs.reference_dict.path)"
                }
            ],
            "id": "#picard_sortvcf.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#main/bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/interval"
                },
                {
                    "type": "string",
                    "id": "#main/job_uuid"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/snp_ref"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/gatk3_unifiedgenotyper/time_metrics",
                    "id": "#main/time_metrics_from_gatk3_unifiedgenotyper"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_sortvcf/time_metrics",
                    "id": "#main/time_metrics_from_picard_sortvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_sortvcf/sorted_vcf",
                    "id": "#main/unifiedgenotyper_sorted_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#gatk3_unifiedgenotyper.cwl",
                    "in": [
                        {
                            "source": "#main/bam_file",
                            "id": "#main/gatk3_unifiedgenotyper/bam_file"
                        },
                        {
                            "source": "#main/interval",
                            "id": "#main/gatk3_unifiedgenotyper/interval"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/gatk3_unifiedgenotyper/job_uuid"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/gatk3_unifiedgenotyper/reference"
                        },
                        {
                            "source": "#main/snp_ref",
                            "id": "#main/gatk3_unifiedgenotyper/snp_ref"
                        }
                    ],
                    "out": [
                        "#main/gatk3_unifiedgenotyper/vcf_list",
                        "#main/gatk3_unifiedgenotyper/time_metrics"
                    ],
                    "id": "#main/gatk3_unifiedgenotyper"
                },
                {
                    "run": "#picard_sortvcf.cwl",
                    "in": [
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/picard_sortvcf/job_uuid"
                        },
                        {
                            "valueFrom": "unifiedgenotyper.srt",
                            "id": "#main/picard_sortvcf/output_prefix"
                        },
                        {
                            "source": "#main/reference",
                            "valueFrom": "$(self.secondaryFiles[1])",
                            "id": "#main/picard_sortvcf/reference_dict"
                        },
                        {
                            "source": "#main/gatk3_unifiedgenotyper/vcf_list",
                            "id": "#main/picard_sortvcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/picard_sortvcf/sorted_vcf",
                        "#main/picard_sortvcf/time_metrics"
                    ],
                    "id": "#main/picard_sortvcf"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
